/* Joe Hopper
 * Homework 3
 * Problem Last: find the biggest number */

#include <stdio.h>

int main(){
  int	num1, num2, num3, num4, /* three numbers to be compared */
    bigger, bigger2, biggest; /* larger and largest number */
  
  printf("Please enter 4 numbers separated by spaces > ");
  scanf("%d%d%d%d", &num1, &num2, &num3, &num4);
  
  if (num1 < num2)
    bigger = num1;
  else
    bigger = num2;
  if (num4 < num3)
    bigger2 = num4;
  else
    bigger2 = num3;

  if (bigger < bigger2)
    biggest = bigger;
  else biggest = bigger2;
  
  printf("%d is the smallest\n", biggest);
  
  return (0);
  
}
